<?php

//  ______          ____       _     _            
// |  ____|        |  _ \     (_)   | |           
// | |__ __ _ _ __ | |_) |_ __ _  __| | __ _  ___ 
// |  __/ _` | '_ \|  _ <| '__| |/ _` |/ _` |/ _ \
// | | | (_| | | | | |_) | |  | | (_| | (_| |  __/
// |_|  \__,_|_| |_|____/|_|  |_|\__,_|\__, |\___|
//                                      __/ |     
//                                     |___/      

/**
 * set the parameters of our plugin to the system
 * 
 * @return void
 */
class FanBridge_SignUp_Widget extends WP_Widget {

	function FanBridge_SignUp_Widget() {
		$widget_ops = array( 
			'description' => 'Adds a FanBridge signup form to your blog'
		);
		$this->WP_Widget('FanBridge_SignUp_Widget', 'FanBridge signup Widget', $widget_ops);
	}

	function widget( $args, $instance) {
		if (!is_array($instance)) {
			$instance = array();
		}
		
		fbridge_sw_form(array_merge($args, $instance));
		
	}
}


/**
 * displays the form based on the parameters sent to
 * FanBridge_SignUp_Widget
 *
 * @return string
 */
function fbridge_sw_form($args) {

	if (!(get_option(FBSG_FORM_PREFIX . FBSG_SN_USER_ID) > 0)) {
		// if we dont have the user id there isn't much to show
		return '';
	}
?>

	<form method="post" id="FbridgeSGWidget" action="<?= get_schema() . FBSG_SUBSCRIBE_ENDPOINT ?>?userid=<?= get_option(FBSG_FORM_PREFIX . FBSG_SN_USER_ID) ?>">
		<h2><?= get_option(FBSG_FORM_PREFIX . FBSG_SN_FORM_TITLE) ?></h2>
		<fieldset>
			<label>Email Address:</label>
			<input type="text" class="textInput" id="<?= FBSG_FORM_PREFIX .  FBSG_SN_EMAIL ?>" name="<?= FBSG_FORM_PREFIX . FBSG_SN_EMAIL ?>" value=""/>

			<?php if (get_option(FBSG_FORM_PREFIX . FBSG_SN_FIRST_NAME . '_show') == 'on') :?>
			<label>First Name:</label>
			<input type="text" class="textInput" id="<?= FBSG_FORM_PREFIX .  FBSG_SN_FIRST_NAME ?>" name="<?= FBSG_FORM_PREFIX . FBSG_SN_FIRST_NAME ?>" value=""/>
			<?php endif; ?>

			<?php if (get_option(FBSG_FORM_PREFIX . FBSG_SN_LAST_NAME . '_show') == 'on') :?>
			<label>Last Name:</label>
			<input type="text" class="textInput" id="<?= FBSG_FORM_PREFIX .  FBSG_SN_LAST_NAME ?>" name="<?= FBSG_FORM_PREFIX . FBSG_SN_LAST_NAME ?>" value=""/>
			<?php endif; ?>

			<?php if (get_option(FBSG_FORM_PREFIX . FBSG_SN_ZIP_CODE . '_show') == 'on') :?>
			<label>Zip/Postal Code:</label>
			<input type="text" class="textInput" id="<?= FBSG_FORM_PREFIX .  FBSG_SN_ZIP_CODE ?>" name="<?= FBSG_FORM_PREFIX . FBSG_SN_ZIP_CODE ?>" value=""/>
			<?php endif; ?>

			<?php if (get_option(FBSG_FORM_PREFIX . FBSG_SN_CITY . '_show') == 'on') :?>
			<label>City:</label>
			<input type="text" class="textInput" id="<?= FBSG_FORM_PREFIX .  FBSG_SN_CITY ?>" name="<?= FBSG_FORM_PREFIX . FBSG_SN_CITY ?>" value=""/>
			<?php endif; ?>

			<?php if (get_option(FBSG_FORM_PREFIX . FBSG_SN_STATE . '_show') == 'on') :?>
			<label>State/Region:</label>
			<input type="text" class="textInput" id="<?= FBSG_FORM_PREFIX .  FBSG_SN_STATE ?>" name="<?= FBSG_FORM_PREFIX . FBSG_SN_STATE ?>" value=""/>
			<?php endif; ?>

			<?php if (get_option(FBSG_FORM_PREFIX . FBSG_SN_COUNTRY . '_show') == 'on') :?>
			<label>Country:</label>
			<select class="selectInput" id="<?= FBSG_FORM_PREFIX .  FBSG_SN_COUNTRY ?>" name="<?= FBSG_FORM_PREFIX . FBSG_SN_COUNTRY ?>">
				<option value="0" data-iso="">-- SELECT COUNTRY --</option>
					<?php country_select() ?>
			</select>
			<?php endif; ?>



		</fieldset>
		<div id="errorField">
		</div>
		<input type="submit" id="_submit-input" name="_submit" class="button" value="Join Mailing List" />
		<div id="attribution">
			<a href="http://<?= FBSG_SITE_URL ?>/?src=fb_wordpress_signup_form&utm_source=wordpress&utm_medium=signup_form&utm_campaign=plugin&utm_content=<?= get_option(FBSG_FORM_PREFIX . FBSG_SN_USER_ID) ?>" target="_blank">Powered by FanBridge</a>
		</div>
		<input id="<?= FBSG_FORM_PREFIX .  'agent' ?>" name="<?= FBSG_FORM_PREFIX .  'agent' ?>" value="<?= 'wpplugin-v' . FBSG_PLUGIN_VERSION ?>" type="hidden"/>
		<?php fbridge_sw_pixel(); ?>
	</form>


<?php
	fbridge_sw_js();
}

/**
 * displays the required js to make the widget working
 *
 * @return string
 */
function fbridge_sw_js() {
?>
<!-- fanbridge widget required js -->
<script type="text/javascript">
/* <![CDATA[ */
	(function($){
		// some defaults
		var _fbridge_sw_prefix = '<?= FBSG_FORM_PREFIX ?>';
		var $fbridge_sw_form = $('#FbridgeSGWidget');
		var $fbridge_sw_result = $('#errorField');


		$fbridge_sw_form.validate({
			onfocusout: false,
			onkeyup: false,
			errorClass: 'invalid',
			showErrors: function(errorMap, errorList) {
           		$.each(errorList, function(key, val) {
					$(val.element).addClass('invalid');
				});
           		$fbridge_sw_result.html('Invalid entries. Please correct the highlighted fields.');
	        },
			unhighlight: function(element, errorClass) {
				$(element).removeClass('invalid');
     			$fbridge_sw_result.html('');
     		},
			rules: {
				<?= FBSG_FORM_PREFIX .  FBSG_SN_EMAIL ?>: {
       				required: true,
       				email: true
     			}
       			<?php if (get_option(FBSG_FORM_PREFIX . FBSG_SN_FIRST_NAME . '_required') == 'on') :?>
				,<?= FBSG_FORM_PREFIX .  FBSG_SN_FIRST_NAME ?>: {
       				required: true
     			}
       			<?php endif; ?>     			
       			<?php if (get_option(FBSG_FORM_PREFIX . FBSG_SN_LAST_NAME . '_required') == 'on') :?>
				,<?= FBSG_FORM_PREFIX .  FBSG_SN_LAST_NAME ?>: {
       				required: true
     			}
       			<?php endif; ?>     
       			<?php if (get_option(FBSG_FORM_PREFIX . FBSG_SN_ZIP_CODE . '_required') == 'on') :?>
				,<?= FBSG_FORM_PREFIX .  FBSG_SN_ZIP_CODE ?>: {
       				required: true
     			}
       			<?php endif; ?>
       			<?php if (get_option(FBSG_FORM_PREFIX . FBSG_SN_CITY . '_required') == 'on') :?>
				,<?= FBSG_FORM_PREFIX .  FBSG_SN_CITY ?>: {
       				required: true
     			}
       			<?php endif; ?>     
       			<?php if (get_option(FBSG_FORM_PREFIX . FBSG_SN_STATE . '_required') == 'on') :?>
				,<?= FBSG_FORM_PREFIX .  FBSG_SN_STATE ?>: {
       				required: true
     			}
       			<?php endif; ?>     
       			<?php if (get_option(FBSG_FORM_PREFIX . FBSG_SN_COUNTRY . '_required') == 'on') :?>
				,<?= FBSG_FORM_PREFIX .  FBSG_SN_COUNTRY ?>: {
       				min: 1
     			}
       			<?php endif; ?>     

			},
			submitHandler: function() {

				$("#FbridgeSGWidget .textInput").removeClass('invalid');
				$fbridge_sw_result.html('');

				// remove the namespace
				var _data = {};
				$.each($fbridge_sw_form.serializeArray(), function(n, each) {
	  				_data[each.name.replace(_fbridge_sw_prefix, '')] = each.value;
				});

				$.ajax({
					url: '<?= get_schema() . FBSG_SUBSCRIBE_ENDPOINT ?>?response=json&userid=<?= get_option(FBSG_FORM_PREFIX . FBSG_SN_USER_ID) ?>',
					data: _data,
					dataType:"jsonp",
					beforeSubmit: function() {
						$fbridge_sw_result.html('');
						$('#_submit-input').attr('disabled', true);
					},
					success: function(res, status, xobj) {
						if(res.status == 'error') {
							$('#_submit-input').attr('disabled', false);
							$.each(res.data.fields, function(key, val) {
								$fbridge_sw_result.html('');
								$('#' + _fbridge_sw_prefix + key).addClass('invalid');
								$fbridge_sw_result.html($fbridge_sw_result.html() + ' ' + val);
							});
						}
						else if(res.status == 'ok') {
							// just being nice
							$('#_submit-input').val('Subscribed!');
							setTimeout(function() {
								$('#_submit-input').val('Join Mailing List');
								$fbridge_sw_form.each (function() { this.reset(); });
							}, 3000);
						}
					},
					error: function() {
							$fbridge_sw_result.html('Oops! An unexpected error ocurred. Please try again.');
					}
				});
			}
		});

		<?php if (get_option(FBSG_FORM_PREFIX . FBSG_GEOIP) == 'on') :?>
		// get the geodata based on the client ip
		$.ajax({
			url: '//geo-ip.herokuapp.com/location.json',
			dataType:"jsonp" ,
			success: function(data) {
				$('#<?= FBSG_FORM_PREFIX .  FBSG_SN_ZIP_CODE ?>').val(data.postal_code);
				$('#<?= FBSG_FORM_PREFIX .  FBSG_SN_CITY ?>').val(data.city);
				$('#<?= FBSG_FORM_PREFIX .  FBSG_SN_STATE ?>').val(data.region_name);
				$("#<?= FBSG_FORM_PREFIX .  FBSG_SN_COUNTRY ?> option[data-iso='" + data.country_code + "']").attr("selected","selected");

			}
		});
		<?php endif; ?>     

	})(jQuery);
/* ]]> */
</script>
<!-- // fanbridge widget required js -->
<?php

}


/**
 * prints the css which makes the form grab inherit styles from the blog theme
 *
 * @return string
 */
function fbridge_sw_inherit_css() {
?>

/* inherit */
/* IE Fixes */

.ie .textInput {
	line-height: 35px;
}


/* Resets */

#FbridgeSGWidget fieldset,
#FbridgeSGWidget h2,
#FbridgeSGWidget,
#FbridgeSGWidget .textInput,
#FbridgeSGWidget .button {
	width: 100% !important;
}

#FbridgeSGWidget * {
	text-transform: none !important;
	background-image: none !important;
	text-indent: 0 !important;
	word-wrap: normal !important;
}

#FbridgeSGWidget fieldset {
	box-sizing: border-box;
	-moz-box-sizing: border-box; // for Mozilla
	-webkit-box-sizing: border-box; // for WebKit
	-ms-box-sizing: border-box; // for IE8
	background-color: inherit;
	width: 100% !important;
	border: 0px !important;
	padding: 0px !important;
	margin: 0px !important;
	font-size: inherit !important;
	-webkit-margin-start: 0;
	-webkit-padding-start: 0;
	-webkit-margin-end: 0;
	-webkit-padding-end: 0;
	-webkit-padding-before: 0;
	-webkit-padding-after: 0;
	-webkit-margin: 0px;
	-webkit-padding: 0px;
}

#FbridgeSGWidget .selectInput {
	height: 35px !important;
	margin: 0px 0px 30px 0px !important;
	padding: 0px !important;
	line-height: 10px !important;
	vertical-align: center !important;
	}

#FbridgeSGWidget .textInput:focus,
#FbridgeSGWidget .emailInput:focus,
#FbridgeSGWidget input[type=submit]:focus {
	outline: none !important;
}

#FbridgeSGWidget input[type=submit],
#FbridgeSGWidget input[type=text] {
	-webkit-appearance: none !important;
}

#FbridgeSGWidget input::-moz-focus-inner /*Remove button padding in FF*/
{ 
    border: 0 !important;
    padding: 0 !important;
}

/* Styling */


#FbridgeSGWidget {
	box-sizing: border-box;
	-moz-box-sizing: border-box; // for Mozilla
	-webkit-box-sizing: border-box; // for WebKit
	-ms-box-sizing: border-box; // for IE8
	font-size: 1em !important;
	background-color: inherit !important;
	color: inherit !important;
	width: 100% !important;
	-moz-border-radius: 3px !important;
	-webkit-border-radius: 3px !important;
	border-radius: 5px !important;
	margin: 0px 0px 15px 0px !important;
}

#FbridgeSGWidget .textInput,
#FbridgeSGWidget .selectInput,
#FbridgeSGWidget .button {
	-moz-border-radius: 3px !important;
	-webkit-border-radius: 3px !important;
	border-radius: 3px !important;
}

#FbridgeSGWidget .textInput,
#FbridgeSGWidget .selectInput {
	border: 1px solid inherit !important;
}

#FbridgeSGWidget label {
	border: 0px !important;
	padding: 0px !important;
	margin-bottom: 5px !important;
}

#FbridgeSGWidget h2 {
	font-size: 1.8em !important;
	border: 0px !important;
	margin: 0px 0px 13px 0px !important;
	padding: 0px !important;
	line-height: 1.2em !important;
	text-align: left !important;
}

#FbridgeSGWidget #errorField,
#FbridgeSGWidget #attribution {
	font-size: .9em !important;
}

#FbridgeSGWidget #errorField {
	color: #d42932 !important;
	margin-bottom: 12px !important;
}

#FbridgeSGWidget #errorField p {
	margin: 0px !important;
	padding: 0px !important;
	border: 0px !important;
}

#FbridgeSGWidget .invalid {
	border: 1% solid #d42932 !important;
	box-shadow: inset 0px 0px 0px 2px #d42932 !important;
}


#FbridgeSGWidget #attribution {
	margin-bottom: -15px !important;
}


#FbridgeSGWidget label,
#FbridgeSGWidget input{
	display: block !important;
}

#FbridgeSGWidget a {
	display: block !important;
	margin: 10px 0px 10px 0px !important;
}

#FbridgeSGWidget a:hover {
	display: block !important;
	text-decoration: underline !important;
}


#FbridgeSGWidget input[type=text] {
	box-sizing: border-box;
	-moz-box-sizing: border-box; // for Mozilla
	-webkit-box-sizing: border-box; // for WebKit
	-ms-box-sizing: border-box; // for IE8
	font-size: inherit;
	padding: 0px 8px 0px 8px !important;
	margin-bottom: 13px !important;
	width: 100% !important;
	height: 35px !important;
	vertical-align: bottom !important;
	font-family: inherit !important;
	font-size: inherit !important;
	color: #333333 !important;
	background-color: #fff !important;
}

#FbridgeSGWidget .selectInput {
	box-sizing: border-box;
	-moz-box-sizing: border-box; // for Mozilla
	-webkit-box-sizing: border-box; // for WebKit
	-ms-box-sizing: border-box; // for IE8
	font-size: inherit;
	padding: 8px 0 8px 5px !important;
	margin-bottom: 13px !important;
	width: 100% !important;
	height: 35px !important;
	vertical-align: bottom !important;
	font-family: inherit !important;
	font-size: inherit !important;
	color: #333333 !important;
	background-color: #fff !important;
}


#FbridgeSGWidget .button{
	vertical-align: baseline !important;
	color: white !important;
	width: 100% !important;
	font-family: inherit;
	font-weight: bold !important;
	background-color: #000 !important;
	background-image: none !important;
	height: auto !important;
	border: none !important;
	padding: 12px 0px 14px 0px !important;
	cursor: pointer !important;
	filter: alpha(opacity=30);
	-moz-opacity:0.30;
	opacity: .30;	
	transition: opacity .2s;
	-moz-transition: opacity .2s; /* Firefox 4 */
	-webkit-transition: opacity .2s; /* Safari and Chrome */
	-o-transition: opacity .2s; /* Opera */

}

#FbridgeSGWidget .button:focus,
#FbridgeSGWidget .button:hover {
	filter: alpha(opacity=40);
	-moz-opacity:0.40;
	opacity: .40;	
}

<?php
}


/**
 * prints the css which makes the form to use the color schema chosen by the
 * user
 *
 * @param $highlight_color string; the custom color chosen by the user
 * @return string
 */
function fbridge_sw_custom_css($highlight_color) {
	?>
/*  custom */
/* IE Fixes */

.ie .textInput {
	line-height: 35px;
}


/* Resets */

#FbridgeSGWidget * {
	text-transform: none !important;
	background-image: none !important;
	text-indent: 0 !important;
	word-wrap: normal !important;
	letter-spacing: normal !important;
	word-break: normal !important;
	box-shadow: none !important;
	text-align: left !important;
}



#FbridgeSGWidget fieldset {
	box-sizing: border-box;
	-moz-box-sizing: border-box; // for Mozilla
	-webkit-box-sizing: border-box; // for WebKit
	-ms-box-sizing: border-box; // for IE8
	padding: 0px;
	margin: 0px;
	-webkit-margin-start: 0;
	-webkit-padding-start: 0;
	-webkit-margin-end: 0;
	-webkit-padding-end: 0;
	-webkit-padding-before: 0;
	-webkit-padding-after: 0;
	-webkit-margin: 0px;
	-webkit-padding: 0px;
	border: 0px !important;
	background-color: #fff !important;
}

#FbridgeSGWidget .textInput:focus,
#FbridgeSGWidget .selectInput,
#FbridgeSGWidget .emailInput:focus,
#FbridgeSGWidget input[type=submit]:focus {
	outline: none;
}

#FbridgeSGWidget input[type=submit],
#FbridgeSGWidget input[type=text] {
	-webkit-appearance: none;
}

#FbridgeSGWidget input::-moz-focus-inner /*Remove button padding in FF*/
{ 
    border: 0;
    padding: 0;
}

/* Styling */

#FbridgeSGWidget {
	box-sizing: border-box;
	-moz-box-sizing: border-box; // for Mozilla
	-webkit-box-sizing: border-box; // for WebKit
	-ms-box-sizing: border-box; // for IE8
	font-size: 14px !important;
	line-height: 15px !important;
	background-color: white !important;
	color: #333333 !important;
	padding: 15px !important;
	-moz-border-radius: 3px !important;
	-webkit-border-radius: 3px !important;
	border-radius: 5px !important;
	margin: 0px 0px 15px 0px !important;
}

#FbridgeSGWidget .textInput,
#FbridgeSGWidget .selectInput,
#FbridgeSGWidget .button {
	-moz-border-radius: 3px !important;
	-webkit-border-radius: 3px !important;
	border-radius: 3px !important;
}

#FbridgeSGWidget .textInput,
#FbridgeSGWidget .selectInput,
#FbridgeSGWidget  {
	border: 1px solid #C5C5C5 !important;
}

#FbridgeSGWidget label {
	color: #333333 !important;
	margin-bottom: 5px !important;
}

#FbridgeSGWidget h2 {
	font-family: 'georgia', 'cambria', 'sans serif' !important;
	background-color: #fff !important;
	color: <?= $highlight_color ?> !important;
	height: auto !important;
	font-weight: normal !important;
    	border: 0 !important;
	line-height: 25px !important;
	font-size: 24px !important;
	text-align: left !important;
	padding: 0px !important;
}

#FbridgeSGWidget h2,
#FbridgeSGWidget .textInput,
#FbridgeSGWidget .selectInput,
#FbridgeSGWidget .button {
	margin: 0px 0px 13px 0px !important;
}


#FbridgeSGWidget #errorField,
#FbridgeSGWidget #attribution {
	font-weight: bold !important;
	font-size: 12px !important;
}

#FbridgeSGWidget #errorField {
	color: #d42932 !important;
	margin-bottom: 12px !important;
}

#FbridgeSGWidget #errorField p {
	margin: 0px !important;
}

#FbridgeSGWidget .invalid {
	border: 1% solid #d42932 !important;
	box-shadow: inset 0px 0px 0px 2px #d42932 !important;
}


#FbridgeSGWidget #attribution {
	margin-bottom: -15px !important;
	color: #9E9E9E !important;
}

#FbridgeSGWidget a {
	background-color: none !important;
	padding: 0 !important;
	color: #9E9E9E !important;
	display: block !important;
	text-decoration: none !important;
	margin: 10px 0px 10px 0px !important;
	border: 0px !important;
	text-align: center !important;
}

#FbridgeSGWidget a:hover {
	background-color: none !important;
	color: #333333 !important;
}

#FbridgeSGWidget label,
#FbridgeSGWidget input{
	display: block;
}

#FbridgeSGWidget .textInput {
	box-sizing: border-box;
	-moz-box-sizing: border-box; // for Mozilla
	-webkit-box-sizing: border-box; // for WebKit
	-ms-box-sizing: border-box; // for IE8
	font-weight: normal !important;
	color: #333333 !important;
	background-color: #fff !important;
	background: none !important;
	padding: 0px 8px 0px 8px !important;
	height: 35px !important;
	vertical-align: bottom !important;
	font-family: 'Helvetica', 'Arial', 'Sans-serif' !important;
}

#FbridgeSGWidget .selectInput {
	box-sizing: border-box;
	-moz-box-sizing: border-box; // for Mozilla
	-webkit-box-sizing: border-box; // for WebKit
	-ms-box-sizing: border-box; // for IE8
	font-weight: normal !important;
	color: #333333 !important;
	background-color: #fff !important;
	background: none !important;
	padding: 8px 0 8px 5px !important;
	height: 35px !important;
	vertical-align: bottom !important;
	font-family: 'Helvetica', 'Arial', 'Sans-serif' !important;
}

#FbridgeSGWidget .textInput,
#FbridgeSGWidget .button,
#FbridgeSGWidget label,
#FbridgeSGWidget a,
#FbridgeSGWidget #attribution,
#FbridgeSGWidget #errorField,
#FbridgeSGWidget .textInput,
#FbridgeSGWidget .selectInput,
#FbridgeSGWidget {
	font-family: 'Helvetica', 'Arial', 'Sans-serif' !important;
}

#FbridgeSGWidget fieldset,
#FbridgeSGWidget h2,
#FbridgeSGWidget,
#FbridgeSGWidget .textInput,
#FbridgeSGWidget .selectInput,
#FbridgeSGWidget .button {
	width: 100% !important;
}

#FbridgeSGWidget .button,
#FbridgeSGWidget label,
#FbridgeSGWidget .textInput,
#FbridgeSGWidget .selectInput,
#FbridgeSGWidget {
	font-size: 14px !important;
}

#FbridgeSGWidget .button,
#FbridgeSGWidget #attribution {
	text-align: center !important;
}

#FbridgeSGWidget a,
#FbridgeSGWidget #attribution,
#FbridgeSGWidget #errorField {
	background-color: none !important;
	font-size: 12px !important;

}

#FbridgeSGWidget .button{
	background-image: none !important;
	height: auto !important;
	vertical-align: baseline !important;
	color: white !important;
	font-size: 14px !important;
	font-weight: bold !important;
	background-color: <?= $highlight_color ?> !important;
	border: none !important;
	padding: 10px 0px 10px 0px !important;
	cursor: pointer !important;
	transition: opacity .2s !important;
	-moz-transition: opacity .2s; /* Firefox 4 */
	-webkit-transition: opacity .2s; /* Safari and Chrome */
	-o-transition: opacity .2s; /* Opera */

}

#FbridgeSGWidget .button:focus,
#FbridgeSGWidget .button:hover {
	filter: alpha(opacity=85);
	-moz-opacity:0.85;
	opacity: .85;	
}


<?php	
}


/**
 * Displays the presense pixel 
 *
 * @param void
 * @return string; the pixel
 */
function fbridge_sw_pixel() {
	if (!do_not_track()) {
		echo "<img style='border:0px' src='//tracking.fanbridge.com/v2/track/image/?bucket=widget&namespace=wpplugin&event=view&properties%5Buser_id%5D=", get_option(FBSG_FORM_PREFIX . FBSG_SN_USER_ID), "&properties%5Bwpversion%5D=", get_bloginfo('version'), "&properties%5Bsite%5D=", @$_SERVER["SERVER_NAME"], "&properties%5Bappearance%5D=", (get_option(FBSG_FORM_PREFIX . FBSG_CUSTOM_COLORS) == 'on' ? 'custom' : 'theme'), "&properties%5Bplugin_version%5D=", FBSG_PLUGIN_VERSION, "&options%5Bidentity%5D=1&options%5Bsafe_mode%5D=0' width='0' height='0'/>";
	}
}

/**
 * check if the DNT (http://donottrack.us/) header is present
 * in that case we wont print the pixel
 *
 * @link http://robert-lerner.com/do-not-track-headers-in-php.php
 * @param void
 * @return boolean; 
 */
function do_not_track() {
	if (isset($_SERVER['HTTP_DNT'])) {
		if ($_SERVER['HTTP_DNT'] == 1) {
			return true;
		}
	}
	elseif(function_exists('getallheaders')) {
		foreach (getallheaders() as $k => $v) {
			if (strtolower($k) === "dnt" && $v == 1) {
				return true;
			}
		}
	}
	return false;
}


/**
 * 
 */
function country_select() {

	// guess what! a country list!
	$countries["US"] = array("id" => 1, "name" => "UNITED STATES");
	$countries["PA"] = array("id" => 155, "name" => "PANAMA");
	$countries["PW"] = array("id" => 154, "name" => "PALAU");
	$countries["PK"] = array("id" => 153, "name" => "PAKISTAN");
	$countries["OM"] = array("id" => 152, "name" => "OMAN");
	$countries["NO"] = array("id" => 151, "name" => "NORWAY");
	$countries["MP"] = array("id" => 150, "name" => "NORTHERN MARIANA ISLANDS");
	$countries["NF"] = array("id" => 149, "name" => "NORFOLK ISLAND");
	$countries["NU"] = array("id" => 148, "name" => "NIUE");
	$countries["NG"] = array("id" => 147, "name" => "NIGERIA");
	$countries["NE"] = array("id" => 146, "name" => "NIGER");
	$countries["NI"] = array("id" => 145, "name" => "NICARAGUA");
	$countries["NZ"] = array("id" => 144, "name" => "NEW ZEALAND");
	$countries["PG"] = array("id" => 156, "name" => "PAPUA NEW GUINEA");
	$countries["PY"] = array("id" => 157, "name" => "PARAGUAY");
	$countries["PE"] = array("id" => 158, "name" => "PERU");
	$countries["KN"] = array("id" => 170, "name" => "SAINT KITTS AND NEVIS");
	$countries["SH"] = array("id" => 169, "name" => "SAINT HELENA");
	$countries["RW"] = array("id" => 168, "name" => "RWANDA");
	$countries["RU"] = array("id" => 167, "name" => "RUSSIAN FEDERATION");
	$countries["RO"] = array("id" => 166, "name" => "ROMANIA");
	$countries["RE"] = array("id" => 165, "name" => "REUNION");
	$countries["QA"] = array("id" => 164, "name" => "QATAR");
	$countries["PR"] = array("id" => 163, "name" => "PUERTO RICO");
	$countries["PT"] = array("id" => 162, "name" => "PORTUGAL");
	$countries["PL"] = array("id" => 161, "name" => "POLAND");
	$countries["PN"] = array("id" => 160, "name" => "PITCAIRN");
	$countries["PH"] = array("id" => 159, "name" => "PHILIPPINES");
	$countries["NC"] = array("id" => 143, "name" => "NEW CALEDONIA");
	$countries["NL"] = array("id" => 141, "name" => "NETHERLANDS");
	$countries["MR"] = array("id" => 126, "name" => "MAURITANIA");
	$countries["MQ"] = array("id" => 125, "name" => "MARTINIQUE");
	$countries["MH"] = array("id" => 124, "name" => "MARSHALL ISLANDS");
	$countries["MT"] = array("id" => 123, "name" => "MALTA");
	$countries["ML"] = array("id" => 122, "name" => "MALI");
	$countries["MV"] = array("id" => 121, "name" => "MALDIVES");
	$countries["MY"] = array("id" => 120, "name" => "MALAYSIA");
	$countries["MW"] = array("id" => 119, "name" => "MALAWI");
	$countries["MG"] = array("id" => 118, "name" => "MADAGASCAR");
	$countries["MK"] = array("id" => 117, "name" => "MACEDONIA");
	$countries["MO"] = array("id" => 116, "name" => "MACAU");
	$countries["LU"] = array("id" => 115, "name" => "LUXEMBOURG");
	$countries["MU"] = array("id" => 127, "name" => "MAURITIUS");
	$countries["YT"] = array("id" => 128, "name" => "MAYOTTE");
	$countries["NP"] = array("id" => 140, "name" => "NEPAL");
	$countries["NR"] = array("id" => 139, "name" => "NAURU");
	$countries["NA"] = array("id" => 138, "name" => "NAMIBIA");
	$countries["MM"] = array("id" => 137, "name" => "MYANMAR");
	$countries["MZ"] = array("id" => 136, "name" => "MOZAMBIQUE");
	$countries["MA"] = array("id" => 135, "name" => "MOROCCO");
	$countries["MS"] = array("id" => 134, "name" => "MONTSERRAT");
	$countries["MN"] = array("id" => 133, "name" => "MONGOLIA");
	$countries["MC"] = array("id" => 132, "name" => "MONACO");
	$countries["MD"] = array("id" => 131, "name" => "MOLDOVA");
	$countries["FM"] = array("id" => 130, "name" => "MICRONESIA");
	$countries["MX"] = array("id" => 129, "name" => "MEXICO");
	$countries["LT"] = array("id" => 114, "name" => "LITHUANIA");
	$countries["RS"] = array("id" => 227, "name" => "SERBIA");
	$countries["AE"] = array("id" => 211, "name" => "UNITED ARAB EMIRATES");
	$countries["UA"] = array("id" => 210, "name" => "UKRAINE");
	$countries["UG"] = array("id" => 209, "name" => "UGANDA");
	$countries["TV"] = array("id" => 208, "name" => "TUVALU");
	$countries["TC"] = array("id" => 207, "name" => "TURKS AND CAICOS ISLANDS");
	$countries["TM"] = array("id" => 206, "name" => "TURKMENISTAN");
	$countries["TR"] = array("id" => 205, "name" => "TURKEY");
	$countries["TN"] = array("id" => 204, "name" => "TUNISIA");
	$countries["TT"] = array("id" => 203, "name" => "TRINIDAD AND TOBAGO");
	$countries["TO"] = array("id" => 202, "name" => "TONGA");
	$countries["TK"] = array("id" => 201, "name" => "TOKELAU");
	$countries["TG"] = array("id" => 200, "name" => "TOGO");
	$countries["UY"] = array("id" => 212, "name" => "URUGUAY");
	$countries["UZ"] = array("id" => 213, "name" => "UZBEKISTAN");
	$countries["BA"] = array("id" => 226, "name" => "BOSNIA AND HERZEGOVINA");
	$countries["KR"] = array("id" => 225, "name" => "SOUTH KOREA");
	$countries["ZW"] = array("id" => 224, "name" => "ZIMBABWE");
	$countries["ZM"] = array("id" => 223, "name" => "ZAMBIA");
	$countries["YE"] = array("id" => 221, "name" => "YEMEN");
	$countries["EH"] = array("id" => 220, "name" => "WESTERN SAHARA");
	$countries["WF"] = array("id" => 219, "name" => "WALLIS AND FUTUNA");
	$countries["VI"] = array("id" => 218, "name" => "VIRGIN ISLANDS, U.S.");
	$countries["VG"] = array("id" => 217, "name" => "VIRGIN ISLANDS, BRITISH");
	$countries["VN"] = array("id" => 216, "name" => "VIETNAM");
	$countries["VE"] = array("id" => 215, "name" => "VENEZUELA");
	$countries["VU"] = array("id" => 214, "name" => "VANUATU");
	$countries["TH"] = array("id" => 199, "name" => "THAILAND");
	$countries["TZ"] = array("id" => 198, "name" => "TANZANIA");
	$countries["SI"] = array("id" => 183, "name" => "SLOVENIA");
	$countries["SK"] = array("id" => 182, "name" => "SLOVAKIA");
	$countries["SG"] = array("id" => 181, "name" => "SINGAPORE");
	$countries["SL"] = array("id" => 180, "name" => "SIERRA LEONE");
	$countries["SC"] = array("id" => 179, "name" => "SEYCHELLES");
	$countries["SN"] = array("id" => 178, "name" => "SENEGAL");
	$countries["SA"] = array("id" => 177, "name" => "SAUDI ARABIA");
	$countries["ST"] = array("id" => 176, "name" => "SAO TOME AND PRINCIPE");
	$countries["SM"] = array("id" => 175, "name" => "SAN MARINO");
	$countries["WS"] = array("id" => 174, "name" => "SAMOA");
	$countries["VC"] = array("id" => 173, "name" => "SAINT VINCENT");
	$countries["PM"] = array("id" => 172, "name" => "SAINT PIERRE AND MIQUELON");
	$countries["SB"] = array("id" => 184, "name" => "SOLOMON ISLANDS");
	$countries["SO"] = array("id" => 185, "name" => "SOMALIA");
	$countries["TJ"] = array("id" => 197, "name" => "TAJIKISTAN");
	$countries["TW"] = array("id" => 196, "name" => "TAIWAN");
	$countries["SY"] = array("id" => 195, "name" => "SYRIAN ARAB REPUBLIC");
	$countries["CH"] = array("id" => 194, "name" => "SWITZERLAND");
	$countries["SE"] = array("id" => 193, "name" => "SWEDEN");
	$countries["SZ"] = array("id" => 192, "name" => "SWAZILAND");
	$countries["SJ"] = array("id" => 191, "name" => "SVALBARD AND JAN MAYEN");
	$countries["SR"] = array("id" => 190, "name" => "SURINAME");
	$countries["SD"] = array("id" => 189, "name" => "SUDAN");
	$countries["LK"] = array("id" => 188, "name" => "SRI LANKA");
	$countries["ES"] = array("id" => 187, "name" => "SPAIN");
	$countries["ZA"] = array("id" => 186, "name" => "SOUTH AFRICA");
	$countries["LC"] = array("id" => 171, "name" => "SAINT LUCIA");
	$countries["DM"] = array("id" => 57, "name" => "DOMINICA");
	$countries["CL"] = array("id" => 42, "name" => "CHILE");
	$countries["TD"] = array("id" => 41, "name" => "CHAD");
	$countries["KY"] = array("id" => 40, "name" => "CAYMAN ISLANDS");
	$countries["CV"] = array("id" => 39, "name" => "CAPE VERDE");
	$countries["CM"] = array("id" => 38, "name" => "CAMEROON");
	$countries["KH"] = array("id" => 37, "name" => "CAMBODIA");
	$countries["BI"] = array("id" => 36, "name" => "BURUNDI");
	$countries["BF"] = array("id" => 35, "name" => "BURKINA FASO");
	$countries["BG"] = array("id" => 34, "name" => "BULGARIA");
	$countries["BN"] = array("id" => 33, "name" => "BRUNEI DARUSSALAM");
	$countries["BR"] = array("id" => 32, "name" => "BRAZIL");
	$countries["BV"] = array("id" => 31, "name" => "BOUVET ISLAND");
	$countries["CN"] = array("id" => 43, "name" => "CHINA");
	$countries["CX"] = array("id" => 44, "name" => "CHRISTMAS ISLAND");
	$countries["DJ"] = array("id" => 56, "name" => "DJIBOUTI");
	$countries["DK"] = array("id" => 55, "name" => "DENMARK");
	$countries["CZ"] = array("id" => 54, "name" => "CZECH REPUBLIC");
	$countries["CY"] = array("id" => 53, "name" => "CYPRUS");
	$countries["CU"] = array("id" => 52, "name" => "CUBA");
	$countries["HR"] = array("id" => 51, "name" => "CROATIA");
	$countries["CI"] = array("id" => 50, "name" => "COTE D'IVOIRE");
	$countries["CR"] = array("id" => 49, "name" => "COSTA RICA");
	$countries["CK"] = array("id" => 48, "name" => "COOK ISLANDS");
	$countries["CG"] = array("id" => 47, "name" => "CONGO");
	$countries["KM"] = array("id" => 46, "name" => "COMOROS");
	$countries["CO"] = array("id" => 45, "name" => "COLOMBIA");
	$countries["BW"] = array("id" => 30, "name" => "BOTSWANA");
	$countries["BO"] = array("id" => 29, "name" => "BOLIVIA");
	$countries["AM"] = array("id" => 14, "name" => "ARMENIA");
	$countries["AR"] = array("id" => 13, "name" => "ARGENTINA");
	$countries["AG"] = array("id" => 12, "name" => "ANTIGUA AND BARBUDA");
	$countries["AQ"] = array("id" => 11, "name" => "ANTARCTICA");
	$countries["AI"] = array("id" => 10, "name" => "ANGUILLA");
	$countries["AO"] = array("id" => 9, "name" => "ANGOLA");
	$countries["AD"] = array("id" => 8, "name" => "ANDORRA");
	$countries["AS"] = array("id" => 7, "name" => "AMERICAN SAMOA");
	$countries["DZ"] = array("id" => 6, "name" => "ALGERIA");
	$countries["AL"] = array("id" => 5, "name" => "ALBANIA");
	$countries["AF"] = array("id" => 4, "name" => "AFGHANISTAN");
	$countries["GB"] = array("id" => 3, "name" => "UNITED KINGDOM");
	$countries["AW"] = array("id" => 15, "name" => "ARUBA");
	$countries["AU"] = array("id" => 16, "name" => "AUSTRALIA");
	$countries["BT"] = array("id" => 28, "name" => "BHUTAN");
	$countries["BM"] = array("id" => 27, "name" => "BERMUDA");
	$countries["BJ"] = array("id" => 26, "name" => "BENIN");
	$countries["BZ"] = array("id" => 25, "name" => "BELIZE");
	$countries["BE"] = array("id" => 24, "name" => "BELGIUM");
	$countries["BY"] = array("id" => 23, "name" => "BELARUS");
	$countries["BB"] = array("id" => 22, "name" => "BARBADOS");
	$countries["BD"] = array("id" => 21, "name" => "BANGLADESH");
	$countries["BH"] = array("id" => 20, "name" => "BAHRAIN");
	$countries["BS"] = array("id" => 19, "name" => "BAHAMAS");
	$countries["AZ"] = array("id" => 18, "name" => "AZERBAIJAN");
	$countries["AT"] = array("id" => 17, "name" => "AUSTRIA");
	$countries["CA"] = array("id" => 2, "name" => "CANADA");
	$countries["LI"] = array("id" => 113, "name" => "LIECHTENSTEIN");
	$countries["IE"] = array("id" => 98, "name" => "IRELAND");
	$countries["IQ"] = array("id" => 97, "name" => "IRAQ");
	$countries["IR"] = array("id" => 96, "name" => "IRAN");
	$countries["ID"] = array("id" => 95, "name" => "INDONESIA");
	$countries["IN"] = array("id" => 94, "name" => "INDIA");
	$countries["IS"] = array("id" => 93, "name" => "ICELAND");
	$countries["HU"] = array("id" => 92, "name" => "HUNGARY");
	$countries["HK"] = array("id" => 91, "name" => "HONG KONG");
	$countries["HN"] = array("id" => 90, "name" => "HONDURAS");
	$countries["HT"] = array("id" => 89, "name" => "HAITI");
	$countries["GY"] = array("id" => 88, "name" => "GUYANA");
	$countries["GW"] = array("id" => 87, "name" => "GUINEA-BISSAU");
	$countries["IL"] = array("id" => 99, "name" => "ISRAEL");
	$countries["IT"] = array("id" => 100, "name" => "ITALY");
	$countries["LR"] = array("id" => 112, "name" => "LIBERIA");
	$countries["LS"] = array("id" => 111, "name" => "LESOTHO");
	$countries["LB"] = array("id" => 110, "name" => "LEBANON");
	$countries["LV"] = array("id" => 109, "name" => "LATVIA");
	$countries["KG"] = array("id" => 108, "name" => "KYRGYZSTAN");
	$countries["KW"] = array("id" => 107, "name" => "KUWAIT");
	$countries["KI"] = array("id" => 106, "name" => "KIRIBATI");
	$countries["KE"] = array("id" => 105, "name" => "KENYA");
	$countries["KZ"] = array("id" => 104, "name" => "KAZAKSTAN");
	$countries["JO"] = array("id" => 103, "name" => "JORDAN");
	$countries["JP"] = array("id" => 102, "name" => "JAPAN");
	$countries["JM"] = array("id" => 101, "name" => "JAMAICA");
	$countries["GN"] = array("id" => 86, "name" => "GUINEA");
	$countries["GT"] = array("id" => 85, "name" => "GUATEMALA");
	$countries["FI"] = array("id" => 70, "name" => "FINLAND");
	$countries["FJ"] = array("id" => 69, "name" => "FIJI");
	$countries["FO"] = array("id" => 68, "name" => "FAROE ISLANDS");
	$countries["FK"] = array("id" => 67, "name" => "FALKLAND ISLANDS");
	$countries["ET"] = array("id" => 66, "name" => "ETHIOPIA");
	$countries["EE"] = array("id" => 65, "name" => "ESTONIA");
	$countries["ER"] = array("id" => 64, "name" => "ERITREA");
	$countries["GQ"] = array("id" => 63, "name" => "EQUATORIAL GUINEA");
	$countries["SV"] = array("id" => 62, "name" => "EL SALVADOR");
	$countries["EG"] = array("id" => 61, "name" => "EGYPT");
	$countries["EC"] = array("id" => 60, "name" => "ECUADOR");
	$countries["TL"] = array("id" => 59, "name" => "EAST TIMOR");
	$countries["FR"] = array("id" => 71, "name" => "FRANCE");
	$countries["GF"] = array("id" => 72, "name" => "FRENCH GUIANA");
	$countries["GU"] = array("id" => 84, "name" => "GUAM");
	$countries["GP"] = array("id" => 83, "name" => "GUADELOUPE");
	$countries["GD"] = array("id" => 82, "name" => "GRENADA");
	$countries["GL"] = array("id" => 81, "name" => "GREENLAND");
	$countries["GR"] = array("id" => 80, "name" => "GREECE");
	$countries["GI"] = array("id" => 79, "name" => "GIBRALTAR");
	$countries["GH"] = array("id" => 78, "name" => "GHANA");
	$countries["DE"] = array("id" => 77, "name" => "GERMANY");
	$countries["GE"] = array("id" => 76, "name" => "GEORGIA");
	$countries["GM"] = array("id" => 75, "name" => "GAMBIA");
	$countries["GA"] = array("id" => 74, "name" => "GABON");
	$countries["PF"] = array("id" => 73, "name" => "FRENCH POLYNESIA");
	$countries["DO"] = array("id" => 58, "name" => "DOMINICAN REPUBLIC");

	foreach($countries as $iso => $values) {
		echo '<option value="', $values['id'], '" data-iso="', $iso, '">', $values['name'], '</option>', "\n";
	}
}

// Gabriel Sosa for FanBridge Inc.
// @pendexgabo
// 2012
